<?php

namespace Drupal\migrate_boost\Drush\Commands;

use Consolidation\AnnotatedCommand\CommandData;
use Drupal\migrate_boost\MigrateBoost;
use Drush\Commands\DrushCommands;

/**
 * Drush integration.
 */
final class MigrateBoostCommands extends DrushCommands {

  /**
   * Enables boost during migrate import.
   *
   * @hook pre-command migrate:import
   */
  public function preCommandMigImport(CommandData $commandData): void {
    $this->boosterEnable();
  }

  /**
   * Enables boost during migrate rollback.
   *
   * @hook pre-command migrate:rollback
   */
  public function preCommandMigRollback(CommandData $commandData): void {
    $this->boosterEnable();
  }

  /**
   * Resets migrate booster and implementation cache.
   *
   * @command migrate:booster:reset
   *
   * @validate-module-enabled migrate_boost
   * @aliases mbr,migrate-booster-reset
   */
  public function boosterReset(): void {
    MigrateBoost::reset();
    $this->logger()->notice(dt('Migrate Boost reset'));
  }

  /**
   * Enables migrate booster and implementation cache.
   *
   * @command migrate:booster:enable
   *
   * @validate-module-enabled migrate_boost
   * @aliases mbe,migrate-booster-enable
   */
  public function boosterEnable(): void {
    MigrateBoost::enable();
    $this->logger()->notice(dt('Migrate Boost enabled'));
  }

}
